@@ -8,7 +8,7 @@ Perl::Dist::WiX::BuildPerl - 4th generation Win32 Perl distribution builder
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::BuildPerl version 1.090.
+This document describes Perl::Dist::WiX::BuildPerl version 1.102.
 
 =head1 DESCRIPTION
 
@@ -24,40 +24,24 @@ build Perl itself.
 =cut
 
 use 5.008001;
-use strict;
-use warnings;
-use Archive::Zip qw( :ERROR_CODES            );
-use English qw( -no_match_vars          );
-use List::MoreUtils qw( any none                );
+use Moose;
+use English qw( -no_match_vars );
+use List::MoreUtils qw( any );
 use Params::Util qw( _HASH _STRING _INSTANCE );
-use Readonly qw( Readonly                );
+use Readonly qw( Readonly );
 use Storable qw( retrieve );
 use File::Spec::Functions qw(
   catdir catfile catpath tmpdir splitpath rel2abs curdir
 );
-use Archive::Tar 1.42 qw();
 use Module::CoreList 2.18 qw();
-require File::Remove;
-require File::pushd;
-require File::ShareDir;
-require File::Copy::Recursive;
-require File::PathList;
-require HTTP::Status;
-require IO::String;
-require IO::Handle;
-require LWP::UserAgent;
-require LWP::Online;
-require PAR::Dist;
-require Probe::Perl;
-require SelectSaver;
-require Template;
-require Win32;
+
+# require IO::Handle;
 require Perl::Dist::WiX::Asset::Perl;
 require Perl::Dist::WiX::Toolchain;
 require File::List::Object;
 
-our $VERSION = '1.100';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.102';
+$VERSION =~ s/_//sm;
 
 Readonly my %CORE_MODULE_FIX => (
 	'IO::Compress'        => 'IO::Compress::Base',
@@ -129,7 +113,7 @@ the default tasklist after the "perl toolchain" is installed.
 
 sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 	my $self = shift;
-	unless ( $self->bin_perl ) {
+	unless ( $self->bin_perl() ) {
 		PDWiX->throw(
 			'Cannot install CPAN modules yet, perl is not installed');
 	}
@@ -170,8 +154,20 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 			next MODULE;
 		}
 
-		if (    ( $module->cpan_file =~ m{/Module-Install-\d}msx )
-			and ( $module->cpan_version > 0.79 ) )
+		# IPC-System-Simple's t\win32.t has the wrong number of tests.
+		if ( $module->cpan_file =~ m{/IPC-System-Simple-1 [.] 19\d}msx ) {
+			$self->_install_cpan_module( $module, 1 );
+			next MODULE;
+		}
+
+		# Time-HiRes is timing-dependent, of course.
+		if ( $module->cpan_file =~ m{/Time-HiRes-}msx ) {
+			$self->_install_cpan_module( $module, 1 );
+			next MODULE;
+		}
+
+		if (    ( $module->cpan_file() =~ m{/Module-Install-\d}msx )
+			and ( $module->cpan_version() > 0.79 ) )
 		{
 
 			# We need a few more modules.
@@ -224,8 +220,7 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 	# Yes, I know that technically it's a core module with
 	# non-core dependencies, and that's ugly. I've just got
 	# to live with it.
-	my $autodie_location =
-	  catfile( $self->image_dir, qw(perl lib autodie.pm) );
+	my $autodie_location = $self->_file(qw(perl lib autodie.pm));
 
 	if ( -e $autodie_location ) {
 		$self->install_modules(qw( Win32::Process IPC::System::Simple ));
@@ -233,31 +228,21 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 
 	# Getting CPANPLUS config file installed if required.
 	my $cpanp_config_location =
-	  catfile( $self->image_dir, qw(perl lib CPANPLUS Config.pm) );
+	  $self->_file(qw(perl lib CPANPLUS Config.pm));
 
 	if ( -e $cpanp_config_location ) {
 
-		# Installing 0.89_02 because of accumulated fixes,
-		# including one in which the config set
-		# by us works better.
-		$self->install_distribution(
-			name             => 'BINGOS/CPANPLUS-0.89_02.tar.gz',
-			mod_name         => 'CPANPLUS',
-			makefilepl_param => ['INSTALLDIRS=perl'],
-			buildpl_param    => [ '--installdirs', 'core' ],
-		);
-
 		$self->trace_line( 1,
 			"Getting CPANPLUS config file ready for patching\n" );
 
 		$self->patch_file(
-			'perl/lib/CPANPLUS/Config.pm' => $self->image_dir,
+			'perl/lib/CPANPLUS/Config.pm' => $self->image_dir(),
 			{ dist => $self, } );
-	} ## end if ( -e $cpanp_config_location)
+	}
 
-	if ( not exists $self->{fragments}->{CPAN} ) {
+	if ( not $self->fragment_exists('CPAN') ) {
 		$self->install_distribution(
-			name             => 'ANDK/CPAN-1.94_52.tar.gz',
+			name             => 'ANDK/CPAN-1.94_54.tar.gz',
 			mod_name         => 'CPAN',
 			makefilepl_param => ['INSTALLDIRS=perl'],
 			buildpl_param    => [ '--installdirs', 'core' ],
@@ -347,7 +332,7 @@ unless (%need) {
 	
 END_PERL
 
-	my $cpan_info_file = catfile( $self->output_dir, 'cpan.info' );
+	my $cpan_info_file = catfile( $self->output_dir(), 'cpan.info' );
 	$cpan_string .= <<"END_PERL";
 nstore \\\@toget, '$cpan_info_file';
 print "Completed collecting information on all modules\\n";
@@ -357,7 +342,7 @@ END_PERL
 
 	# Dump the CPAN script to a temp file and execute
 	$self->trace_line( 1, "Running upgrade of all modules\n" );
-	my $cpan_file = catfile( $self->build_dir, 'cpan_string.pl' );
+	my $cpan_file = catfile( $self->build_dir(), 'cpan_string.pl' );
   SCOPE: {
 		my $CPAN_FILE;
 		open $CPAN_FILE, '>', $cpan_file
@@ -367,7 +352,7 @@ END_PERL
 		close $CPAN_FILE
 		  or PDWiX->throw("CPAN script close failed: $OS_ERROR");
 	}
-	$self->_run3( $self->bin_perl, $cpan_file )
+	$self->_run3( $self->bin_perl(), $cpan_file )
 	  or PDWiX->throw('CPAN script execution failed');
 	PDWiX->throw('Failure detected during cpan upgrade, stopping')
 	  if $CHILD_ERROR;
@@ -375,12 +360,33 @@ END_PERL
 	return $cpan_info_file;
 } ## end sub _get_cpan_upgrades_list
 
+sub _install_location {
+	my ( $self, $core ) = @_;
+	my $portable = $self->portable();
+	if ($core) {
+		return (
+			makefilepl_param => ['INSTALLDIRS=perl'],
+			buildpl_param    => [ '--installdirs', 'core' ],
+		);
+	} elsif ($portable) {
+		return (
+			makefilepl_param => ['INSTALLDIRS=site'],
+			buildpl_param    => [ '--installdirs', 'site' ],
+		);
+	} else {
+		return (
+			makefilepl_param => ['INSTALLDIRS=vendor'],
+			buildpl_param    => [ '--installdirs', 'vendor' ],
+		);
+	}
+} ## end sub _install_location
+
 sub _install_cpan_module {
 	my ( $self, $module, $force ) = @_;
-	$force = $force or $self->force;
-	my $perl_version = $self->perl_version_literal;
-	my $module_id    = $self->_module_fix( $module->id );
-	my $module_file  = substr $module->cpan_file, 5;
+	$force = $force or $self->force();
+	my $perl_version = $self->perl_version_literal();
+	my $module_id    = $self->_module_fix( $module->id() );
+	my $module_file  = substr $module->cpan_file(), 5;
 #<<<
 	my $core =
 	  exists $Module::CoreList::version{ $perl_version }{ $module_id }
@@ -389,15 +395,7 @@ sub _install_cpan_module {
 	$self->install_distribution(
 		name     => $module_file,
 		mod_name => $module_id,
-		$core
-		  ? (
-		      makefilepl_param => ['INSTALLDIRS=perl'],
-			  buildpl_param => ['--installdirs', 'core'],
-		    )
-		  : (
-		      makefilepl_param => ['INSTALLDIRS=vendor'],
-			  buildpl_param => ['--installdirs', 'vendor'],
-		    ),
+		$self->_install_location($core),
 		$force
 		  ? ( force => 1 )
 		  : (),
@@ -410,18 +408,18 @@ sub _skip_upgrade {
 	my ( $self, $module ) = @_;
 
 	# DON'T try to install Perl.
-	return 1 if $module->cpan_file =~ m{/perl-5 [.]}msx;
+	return 1 if $module->cpan_file() =~ m{/perl-5 [.]}msx;
 
 	# DON'T try to install Term::ReadKey, we
 	# already upgraded it.
-	return 1 if $module->id eq 'Term::ReadKey';
+	return 1 if $module->id() eq 'Term::ReadKey';
 
 	# DON'T try to install Win32API::Registry, we
 	# already upgraded it as far as we can.
-	return 1 if $module->id eq 'Win32API::Registry';
+	return 1 if $module->id() eq 'Win32API::Registry';
 
 	# If the ID is CGI::Carp, there's a bug in the index.
-	return 1 if $module->id eq 'CGI::Carp';
+	return 1 if $module->id() eq 'CGI::Carp';
 
 	# If the ID is ExtUtils::MakeMaker, we've already installed it.
 	# There were some files gotten rid of after 6.50, so
@@ -429,7 +427,13 @@ sub _skip_upgrade {
 	# those files using it.
 
 	# This code is in here for safety as of yet.
-	return 1 if $module->cpan_file =~ m{/ExtUtils-MakeMaker-6 [.] 50}msx;
+	return 1 if $module->cpan_file() =~ m{/ExtUtils-MakeMaker-6 [.] 50}msx;
+
+	# Skip Test-Harness 3.19, waiting on RT#53912.
+	return 1 if $module->cpan_file() =~ m{/Test-Harness-3 [.] 19}msx;
+
+	# Skip B::C, it does not install on 5.8.9.
+	return 1 if $module->cpan_file() =~ m{/B-C-1 [.]}msx;
 
 	return 0;
 } ## end sub _skip_upgrade
@@ -453,7 +457,7 @@ the default tasklist after the "c toolchain" is installed.
 # Just hand off to the larger set of Perl install methods.
 sub install_perl {
 	my $self                = shift;
-	my $install_perl_method = 'install_perl_' . $self->perl_version;
+	my $install_perl_method = 'install_perl_' . $self->perl_version();
 	unless ( $self->can($install_perl_method) ) {
 		PDWiX->throw(
 			"Cannot generate perl, missing $install_perl_method method in "
@@ -462,12 +466,12 @@ sub install_perl {
 	$self->$install_perl_method(@_);
 
 	$self->add_to_fragment( 'perl',
-		[ catfile( $self->image_dir, qw(perl lib perllocal.pod) ) ] );
+		[ $self->_file(qw(perl lib perllocal.pod)) ] );
 
 	return 1;
 } ## end sub install_perl
 
-=head2 install_perl_* (* = 589, 5100, or 5101)
+=head2 install_perl_* (* = git, 589, 5100, or 5101)
 
 	$self->install_perl_5100;
 
@@ -526,10 +530,10 @@ sub install_perl_589 {
 	# fails early if there's a problem
 	$self->trace_line( 1, "Pregenerating toolchain...\n" );
 	my $toolchain = Perl::Dist::WiX::Toolchain->new(
-		perl_version => $self->perl_version_literal,
-		cpan         => $self->cpan->as_string
+		perl_version => $self->perl_version_literal(),
+		cpan         => $self->cpan()->as_string()
 	) or PDWiX->throw('Failed to resolve toolchain modules');
-	unless ( eval { $toolchain->delegate; 1; } ) {
+	unless ( eval { $toolchain->delegate(); 1; } ) {
 		PDWiX::Caught->throw(
 			message => 'Delegation error occured',
 			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
@@ -541,10 +545,10 @@ sub install_perl_589 {
 			info    => $toolchain->get_error() );
 	}
 
-	$self->{toolchain} = $toolchain;
+	$self->_set_toolchain($toolchain);
 
 	# Make the perl directory if it hasn't been made alreafy.
-	$self->make_path( catdir( $self->image_dir, 'perl' ) );
+	$self->_make_path( $self->_dir('perl') );
 
 	# Install the main perl distributions
 	$self->install_perl_bin(
@@ -578,17 +582,17 @@ sub install_perl_bin {
 		@_,
 	);
 
-	unless ( $self->bin_make ) {
+	unless ( $self->bin_make() ) {
 		PDWiX->throw('Cannot build Perl yet, no bin_make defined');
 	}
 
 	$perl->install();
 
 	# Should have a perl to use now.
-	$self->{bin_perl} = catfile( $self->image_dir, qw/perl bin perl.exe/ );
+	$self->_set_bin_perl( $self->_file(qw/perl bin perl.exe/) );
 
 	# Add to the environment variables
-	$self->add_env_path( 'perl', 'bin' );
+	$self->add_path( 'perl', 'bin' );
 
 	return 1;
 } ## end sub install_perl_bin
@@ -604,10 +608,10 @@ sub install_perl_5100 {
 	# fails early if there's a problem
 	$self->trace_line( 1, "Pregenerating toolchain...\n" );
 	my $toolchain = Perl::Dist::WiX::Toolchain->new(
-		perl_version => $self->perl_version_literal,
-		cpan         => $self->cpan->as_string
+		perl_version => $self->perl_version_literal(),
+		cpan         => $self->cpan()->as_string()
 	) or PDWiX->throw('Failed to resolve toolchain modules');
-	unless ( eval { $toolchain->delegate; 1; } ) {
+	unless ( eval { $toolchain->delegate(); 1; } ) {
 		PDWiX::Caught->throw(
 			message => 'Delegation error occured',
 			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
@@ -619,10 +623,10 @@ sub install_perl_5100 {
 			info    => $toolchain->get_error() );
 	}
 
-	$self->{toolchain} = $toolchain;
+	$self->_set_toolchain($toolchain);
 
 	# Make the perl directory if it hasn't been made already.
-	$self->make_path( catdir( $self->image_dir, 'perl' ) );
+	$self->_make_path( $self->_dir('perl') );
 
 	# Install the main binary
 	$self->install_perl_bin(
@@ -672,10 +676,10 @@ sub install_perl_5101 {
 			info    => $toolchain->get_error() );
 	}
 
-	$self->{toolchain} = $toolchain;
+	$self->_set_toolchain($toolchain);
 
 	# Make the perl directory if it hasn't been made already.
-	$self->make_path( catdir( $self->image_dir, 'perl' ) );
+	$self->_make_path( $self->_dir('perl') );
 
 	# Install the main binary
 	$self->install_perl_bin(
@@ -701,6 +705,60 @@ sub install_perl_5101 {
 	return 1;
 } ## end sub install_perl_5101
 
+sub install_perl_git {
+	my $self = shift;
+
+	# Prefetch and predelegate the toolchain so that it
+	# fails early if there's a problem
+	$self->trace_line( 1, "Pregenerating toolchain...\n" );
+	my $toolchain = Perl::Dist::WiX::Toolchain->new(
+		perl_version => $self->perl_version_literal,
+		cpan         => $self->cpan->as_string
+	) or PDWiX->throw('Failed to resolve toolchain modules');
+	unless ( eval { $toolchain->delegate; 1; } ) {
+		PDWiX::Caught->throw(
+			message => 'Delegation error occured',
+			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
+		);
+	}
+	if ( defined $toolchain->get_error() ) {
+		PDWiX::Caught->throw(
+			message => 'Failed to generate toolchain distributions',
+			info    => $toolchain->get_error() );
+	}
+
+	$self->_set_toolchain($toolchain);
+
+	# Make the perl directory if it hasn't been made already.
+	$self->_make_path( $self->_dir('perl') );
+
+	my $checkout = $self->git_checkout();
+
+	# Install the main binary
+	$self->install_perl_bin(
+		name       => 'perl',
+		url        => URI::file->new($checkout)->as_string(),
+		file       => $checkout,
+		unpack_to  => 'perl',
+		install_to => 'perl',
+		toolchain  => $toolchain,
+		patch      => [ qw{
+			  lib/CPAN/Config.pm
+			  win32/config.gc
+			  win32/config_sh.PL
+			  win32/config_H.gc
+			  }
+		],
+		license => {
+			'perl-git/Readme'   => 'perl/Readme',
+			'perl-git/Artistic' => 'perl/Artistic',
+			'perl-git/Copying'  => 'perl/Copying',
+		},
+		git => $self->git_describe(),
+	);
+
+	return 1;
+} ## end sub install_perl_git
 
 #####################################################################
 # Perl Toolchain Support
@@ -721,7 +779,7 @@ the default tasklist after the perl interpreter is installed.
 
 sub install_perl_toolchain {
 	my $self      = shift;
-	my $toolchain = $self->toolchain;
+	my $toolchain = $self->_get_toolchain();
 
 	if ( 0 == $toolchain->dist_count() ) {
 		PDWiX->throw('Toolchain did not get collected');
@@ -734,7 +792,7 @@ sub install_perl_toolchain {
 		my $automated_testing = 0;
 		my $release_testing   = 0;
 		my $overwritable      = 0;
-		my $force             = $self->force;
+		my $force             = $self->force();
 		if ( $dist =~ /Scalar-List-Util/msx ) {
 
 			# Does something weird with tainting
@@ -763,12 +821,17 @@ sub install_perl_toolchain {
 			# Upgrading to this version, instead...
 			$dist = 'STSI/TermReadKey-2.30.01.tar.gz';
 		}
+		if ( $dist =~ /Test-Harness-3 [.] 20/msx ) {
+
+			# 3.20 has a test bug... waiting for RT#54028
+			$force = 1;
+		}
 		if ( $dist =~ /CPAN-1 [.] 9402/msx ) {
 
 			# 1.9402 fails its tests... ANDK says it's a test bug.
 			# Alias agrees that we include 1.94_51 because of the fix
 			# for the Win32 file:// bug.
-			$dist  = 'ANDK/CPAN-1.94_52.tar.gz';
+			$dist  = 'ANDK/CPAN-1.94_53.tar.gz';
 			$force = 1;
 		}
 		if ( $dist =~ /ExtUtils-ParseXS-2[.]20(?:02)?[.]tar[.]gz/msx ) {
@@ -781,11 +844,6 @@ sub install_perl_toolchain {
 			# 0.31 does not include a Makefile.PL.
 			$dist = 'BLM/Win32API-Registry-0.30.tar.gz';
 		}
-		if ( $dist =~ /Module-Build-/msx ) {
-
-			# 0.31 does not include a Makefile.PL.
-			$dist = 'DAGOLDEN/Module-Build-0.3500_01.tar.gz';
-		}
 		if ( $dist =~ /ExtUtils-MakeMaker-/msx ) {
 
 			# There are modules that overwrite portions of this one.
@@ -814,15 +872,7 @@ sub install_perl_toolchain {
 			automated_testing => $automated_testing,
 			release_testing   => $release_testing,
 			overwritable      => $overwritable,
-			$core
-			  ? (
-				  makefilepl_param => ['INSTALLDIRS=perl'],
-				  buildpl_param => ['--installdirs', 'core'],
-				)
-			  : (
-				  makefilepl_param => ['INSTALLDIRS=vendor'],
-				  buildpl_param => ['--installdirs', 'vendor'],
-			    ),
+			$self->_install_location($core),
 		);
 #>>>
 	} ## end foreach my $dist ( $toolchain...)
@@ -886,7 +936,7 @@ L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Curtis Jewell.
+Copyright 2009 - 2010 Curtis Jewell.
 
 Copyright 2008 - 2009 Adam Kennedy.
 
