@@ -8,7 +8,7 @@ Perl::Dist::WiX::Checkpoint - Checkpoint support for Perl::Dist::WiX
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Checkpoint version 1.100.
+This document describes Perl::Dist::WiX::Checkpoint version 1.102.
 
 =head1 DESCRIPTION
 
@@ -29,97 +29,20 @@ support checkpointing.
 =head1 INTERFACE
 
 There are 2 portions to the interface to this module - the parameters to 
-L<new()|Perl::Dist::WiX/new> (listed under C<Parameters> below), and the 
+L<new()|Perl::Dist::WiX/new> (documented in that module), and the 
 object calls that Perl::Dist::WiX uses to coordinate checkpointing.
 
-=head2 Parameters
-
-=head3 tasklist
-
-	$dist = Perl::Dist::WiX->new(
-		# ...
-		tasklist => [
-			# Install the core C toolchain
-			'install_c_toolchain',
-
-			# Install any additional C libraries
-			'install_c_libraries',
-
-			# Install the Perl binary
-			'install_perl',
-
-			# Install the Perl toolchain
-			'install_perl_toolchain',
-
-			# Install additional Perl modules
-			'install_cpan_upgrades',
-
-			# Install the Win32 extras
-			'install_win32_extras',
-
-			# Apply optional portability support
-			'install_portable',
-
-			# Remove waste and temporary files
-			'remove_waste',
-
-			# Regenerate file fragments
-			'regenerate_fragments',
-			
-			# Install any extra custom non-Perl software on top of Perl.
-			# This is primarily added for the benefit of Parrot.
-			'install_custom',
-
-			# Write out the distributions
-			'write',
-		];
-		# ...
-	);
-
-This is the parameter that specifies what tasks to execute.  The names 
-are of object methods of Perl::Dist::WiX (or its subclasses) that will be 
-executed in order, and their task numbers (as used below) will begin with 
-1 and increment in sequence.
-
-The default task list for Perl::Dist::WiX is as shown above.  Subclasses should
-insert their tasks in this list, rather than overriding routines shown above.
-
-=head3 checkpoint_after
-
-C<checkpoint_after> is given an arrayref of task numbers.  After each task in 
-the list, Perl::Dist::WiX will stop and save a checkpoint.
-
-[ 0 ] is the default, meaning that you do not wish to save a checkpoint anywhere.
-
-=head3 checkpoint_stop
-
-C<checkpoint_stop> stops execution after the specified task if no error has 
-happened before then.
-
-0 is the default, meaning that you do not wish to stop unless an error occurs.
-
-=head3 checkpoint_before
-
-C<checkpoint_before> is given an integer to know when to load a checkpoint.
-Unlike the other parameters, this is based on the task number that is GOING 
-to execute, rather than the task number that just executed, so that if a 
-checkpoint was saved after (for example) task 5, this parameter should be 6
-in order to load the checkpoint and start on task 6.
-
-0 is the default, meaning that you do not wish to stop unless an error occurs.
-
 =cut
 
 use 5.008001;
-use strict;
-use warnings;
+use Moose;
 use English qw( -no_match_vars );
-use List::Util qw( first          );
+use List::Util qw( first );
 use File::Spec::Functions qw( catdir catfile );
 use File::Remove qw();
 
-our $VERSION = '1.100';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.102';
+$VERSION =~ s/_//ms;
 
 #####################################################################
 # Checkpoint Support
@@ -145,12 +68,12 @@ sub checkpoint_task {
 	my $step = shift;
 
 	# Are we loading at this step?
-	if ( $self->checkpoint_before == $step ) {
-		$self->checkpoint_load;
+	if ( $self->checkpoint_before() == $step ) {
+		$self->checkpoint_load();
 	}
 
 	# Skip if we are loading later on
-	if ( $self->checkpoint_before > $step ) {
+	if ( $self->checkpoint_before() > $step ) {
 		$self->trace_line( 0, "Skipping $task (step $step.)\n" );
 	} else {
 		my $t = time;
@@ -162,12 +85,12 @@ sub checkpoint_task {
 	}
 
 	# Are we saving at this step?
-	if ( defined first { $step == $_ } @{ $self->checkpoint_after } ) {
-		$self->checkpoint_save;
+	if ( defined first { $step == $_ } @{ $self->checkpoint_after() } ) {
+		$self->checkpoint_save();
 	}
 
 	# Are we stopping at this step?
-	if ( $self->checkpoint_stop == $step ) {
+	if ( $self->checkpoint_stop() == $step ) {
 		return 0;
 	}
 
@@ -181,7 +104,8 @@ Returns the file that the Perl::Dist::WiX object is stored in.
 =cut
 
 sub checkpoint_file {
-	return catfile( $_[0]->checkpoint_dir, 'self.dat' );
+	my $self = shift;
+	return catfile( $self->checkpoint_dir(), 'self.dat' );
 }
 
 =head2 checkpoint_self
@@ -209,14 +133,13 @@ sub checkpoint_save {
 
 	# Clear out any existing checkpoint.
 	$self->trace_line( 1, "Removing old checkpoint\n" );
-	$self->{checkpoint_dir} = catfile( $self->temp_dir, 'checkpoint' );
-	$self->remake_path( $self->checkpoint_dir );
+	$self->remake_path( $self->checkpoint_dir() );
 
 	# Copy the paths into the checkpoint directory.
 	$self->trace_line( 1, "Copying checkpoint directories...\n" );
 	foreach my $dir (qw{ build_dir download_dir image_dir output_dir }) {
 		my $from = $self->$dir();
-		my $to = catdir( $self->checkpoint_dir, $dir );
+		my $to = catdir( $self->checkpoint_dir(), $dir );
 		$self->_copy( $from => $to );
 	}
 
@@ -228,20 +151,19 @@ sub checkpoint_save {
 		checkpoint_before => 0,
 		checkpoint_after  => [0],
 		checkpoint_stop   => 0,
-		tt_exists         => ( defined $self->{template_toolkit} ? 1 : 0 ),
-		template_toolkit  => undef,
+		patch_template    => undef,
 		user_agent        => undef,
 		'_guidgen'        => undef,
-		misc              => undef,
+		'_trace_object'   => undef,
 	};
 
 	local $Storable::Deparse = 1;
-	Storable::nstore( $copy, $self->checkpoint_file );
+	Storable::nstore( $copy, $self->checkpoint_file() );
 
 	return 1;
 } ## end sub checkpoint_save
 
-=head2 checkpoint_save
+=head2 checkpoint_load
 
 Restores a checkpoint saved to the checkpoint subdirectory of 
 L<Perl::Dist::WiX-E<gt>temp_dir|Perl::Dist::WiX/temp_dir> with 
@@ -251,48 +173,39 @@ L</checkpoint_save>.
 
 sub checkpoint_load {
 	my $self = shift;
-	unless ( $self->temp_dir ) {
-		PDWiX->throw('Checkpoints require a temp_dir to be set');
-	}
 
 	# Does the checkpoint exist?
 	$self->trace_line( 1, "Removing old checkpoint\n" );
-	$self->{checkpoint_dir} =
-	  File::Spec->catfile( $self->temp_dir, 'checkpoint', );
-	unless ( -d $self->checkpoint_dir ) {
+	unless ( -d $self->checkpoint_dir() ) {
 		PDWiX->throw('Failed to find checkpoint directory');
 	}
 
 	# If we want a future checkpoint, save it.
-	my $checkpoint_after = $self->{checkpoint_after} || 0;
-	my $checkpoint_stop  = $self->{checkpoint_stop}  || 0;
+	my $checkpoint_after = $self->checkpoint_after() || 0;
+	my $checkpoint_stop  = $self->checkpoint_stop()  || 0;
 
 	# Load the stored hash over our object
 	local $Storable::Eval = 1;
-	my $stored = Storable::retrieve( $self->checkpoint_file );
+	my $stored = Storable::retrieve( $self->checkpoint_file() );
 	%{$self} = %{$stored};
 
 	# Restore any possible future checkpoint.
-	$self->{checkpoint_after} = $checkpoint_after;
-	$self->{checkpoint_stop}  = $checkpoint_stop;
-
-	# Reload the template object if it existed before.
-	if ( $self->{tt_exists} ) {
-		$self->patch_template();
-		delete $self->{tt_exists};
-	}
+	$self->_set_checkpoint_after($checkpoint_after);
+	$self->_set_checkpoint_stop($checkpoint_stop);
 
 	## no critic(ProtectPrivateSubs)
-
 	# Reload the misc object.
+	$self->_set_trace_object(undef);
 	WiX3::Trace::Object->_clear_instance();
 	WiX3::Traceable->_clear_instance();
-	$self->{misc} = WiX3::Traceable->new( tracelevel => $self->{trace} );
+	$self->_set_trace_object(
+		WiX3::Traceable->new( tracelevel => $self->trace() ) );
 
+	$self->_set_guidgen(undef);
 	WiX3::XML::GeneratesGUID::Object->_clear_instance();
-	$self->{_guidgen} =
-	  WiX3::XML::GeneratesGUID::Object->new(
-		_sitename => $self->{sitename} );
+	$self->_set_guidgen(
+		WiX3::XML::GeneratesGUID::Object->new(
+			_sitename => $self->sitename() ) );
 
 	# Pull all the directories out of the storage.
 	$self->trace_line( 0, "Restoring checkpoint directories...\n" );
@@ -354,7 +267,7 @@ L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Curtis Jewell.
+Copyright 2009 - 2010 Curtis Jewell.
 
 Copyright 2008 - 2009 Adam Kennedy.
 
