@@ -1,20 +1,36 @@
 package Perl::Dist::WiX::DirectoryCache;
 
-#####################################################################
-# Perl::Dist::WiX::DirectoryCache - Class containing cache of
-#   <Directory> tags objects.
-#
-# Copyright 2009 Curtis Jewell
-#
-# License is the same as perl. See Wix.pm for details.
-#
+=pod
+
+=head1 NAME
+
+Perl::Dist::WiX::DirectoryCache - Cache of <Directory> tag objects.
+
+=head1 VERSION
+
+This document describes Perl::Dist::WiX::DirectoryCache version 1.102.
+
+=head1 DESCRIPTION
+
+	# TODO.
+
+=head1 SYNOPSIS
+
+	# TODO.
+
+=head1 INTERFACE
+
+	# TODO.
+	
+=cut
+
 use 5.008001;
 use MooseX::Singleton;
 use WiX3::XML::Directory;
 use MooseX::AttributeHelpers;
 
-our $VERSION = '1.100';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.102';
+$VERSION =~ s/_//ms;
 
 #####################################################################
 # Accessors:
@@ -79,3 +95,46 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
+=pod
+
+=head1 DIAGNOSTICS
+
+See L<Perl::Dist::WiX::Diagnostics|Perl::Dist::WiX::Diagnostics> for a list of
+exceptions that this module can throw.
+
+=head1 BUGS AND LIMITATIONS (SUPPORT)
+
+Bugs should be reported via: 
+
+1) The CPAN bug tracker at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist-WiX>
+if you have an account there.
+
+2) Email to E<lt>bug-Perl-Dist-WiX@rt.cpan.orgE<gt> if you do not.
+
+For other issues, contact the topmost author.
+
+=head1 AUTHORS
+
+Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
+
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+
+=head1 SEE ALSO
+
+L<Perl::Dist::WiX|Perl::Dist::WiX>, 
+L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2009 - 2010 Curtis Jewell.
+
+Copyright 2008 - 2009 Adam Kennedy.
+
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the
+LICENSE file included with this distribution.
+
+=cut
