@@ -1,26 +1,43 @@
 package Perl::Dist::WiX::IconArray;
 
-####################################################################
-# Perl::Dist::WiX::IconArray - Object that represents a list of <Icon> tags.
-#
-# Copyright 2009 Curtis Jewell
-#
-# License is the same as perl. See Wix.pm for details.
-#
+=pod
+
+=head1 NAME
+
+Perl::Dist::WiX::IconArray - A list of <Icon> tags.
+
+=head1 VERSION
+
+This document describes Perl::Dist::WiX::IconArray version 1.102.
+
+=head1 DESCRIPTION
+
+	# TODO.
+
+=head1 SYNOPSIS
+
+	# TODO.
+
+=head1 INTERFACE
+
+	# TODO.
+	
+=cut
+
 use 5.008001;
 use Moose;
 use MooseX::AttributeHelpers;
 use Params::Util qw( _STRING   );
 use File::Spec::Functions qw( splitpath );
-require Perl::Dist::WiX::Icon;
+require Perl::Dist::WiX::Tag::Icon;
 
-our $VERSION = '1.100';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.102';
+$VERSION =~ s/_//ms;
 
 has _icon => (
 	metaclass => 'Collection::Array',
 	is        => 'rw',
-	isa       => 'ArrayRef[Perl::Dist::WiX::Icon]',
+	isa       => 'ArrayRef[Perl::Dist::WiX::Tag::Icon]',
 	default   => sub { [] },
 	provides  => {
 		'push'     => '_push_icon',
@@ -52,13 +69,13 @@ sub add_icon {
 	unless ( defined _STRING($pathname_target) ) {
 		PDWiX::Parameter->throw(
 			parameter => 'pathname_target',
-			where     => '::Icons->add_icon'
+			where     => '::IconArray->add_icon'
 		);
 	}
 	unless ( defined _STRING($pathname_icon) ) {
 		PDWiX::Parameter->throw(
 			parameter => 'pathname_icon',
-			where     => '::Icons->add_icon'
+			where     => '::IconArray->add_icon'
 		);
 	}
 
@@ -82,7 +99,7 @@ sub add_icon {
 
 	# Add icon to our list.
 	$self->_push_icon(
-		Perl::Dist::WiX::Icon->new(
+		Perl::Dist::WiX::Tag::Icon->new(
 			sourcefile  => $pathname_icon,
 			target_type => $target_type,
 			id          => $id
@@ -100,6 +117,7 @@ sub add_icon {
 #   Id of icon.
 
 sub search_icon {
+	## no critic (ProhibitExplicitReturnUndef)
 	my ( $self, $pathname_icon, $target_type ) = @_;
 
 	# Check parameters
@@ -109,13 +127,13 @@ sub search_icon {
 	unless ( defined _STRING($target_type) ) {
 		PDWiX::Parameter->throw(
 			parameter => 'target_type',
-			where     => '::Icons->search_icon'
+			where     => '::IconArray->search_icon'
 		);
 	}
 	unless ( defined _STRING($pathname_icon) ) {
 		PDWiX::Parameter->throw(
 			parameter => 'pathname_icon',
-			where     => '::Icons->search_icon'
+			where     => '::IconArray->search_icon'
 		);
 	}
 
@@ -152,7 +170,7 @@ sub as_string {
 	foreach my $icon ( $self->_get_icon_array() ) {
 		my $id   = $icon->get_id();
 		my $file = $icon->get_sourcefile();
-		$answer .= "  <Icon Id='I_$id' SourceFile='$file' />\n";
+		$answer .= "    <Icon Id='I_$id' SourceFile='$file' />\n";
 	}
 
 	return $answer;
@@ -162,3 +180,48 @@ no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
+
+__END__
+
+=pod
+
+=head1 DIAGNOSTICS
+
+See L<Perl::Dist::WiX::Diagnostics|Perl::Dist::WiX::Diagnostics> for a list of
+exceptions that this module can throw.
+
+=head1 BUGS AND LIMITATIONS (SUPPORT)
+
+Bugs should be reported via: 
+
+1) The CPAN bug tracker at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist-WiX>
+if you have an account there.
+
+2) Email to E<lt>bug-Perl-Dist-WiX@rt.cpan.orgE<gt> if you do not.
+
+For other issues, contact the topmost author.
+
+=head1 AUTHORS
+
+Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
+
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+
+=head1 SEE ALSO
+
+L<Perl::Dist::WiX|Perl::Dist::WiX>, 
+L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2009 - 2010 Curtis Jewell.
+
+Copyright 2008 - 2009 Adam Kennedy.
+
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the
+LICENSE file included with this distribution.
+
+=cut
